@@ -1,10 +1,12 @@
-"""Implementation of the CoordConv modules from https://arxiv.org/abs/1807.03247
-
+"""
+Implementation of the CoordConv modules from https://arxiv.org/abs/1807.03247
 """
 
 import torch
 import torch.nn as nn
 
+__all__ = ["append_coords", "AddCoords", "CoordConv"]
+
 
 def append_coords(input_tensor, with_r=False):
     batch_size, _, x_dim, y_dim = input_tensor.size()
@@ -21,42 +23,33 @@ def append_coords(input_tensor, with_r=False):
     xx_channel = xx_channel.repeat(batch_size, 1, 1, 1).transpose(2, 3)
     yy_channel = yy_channel.repeat(batch_size, 1, 1, 1).transpose(2, 3)
 
-    ret = torch.cat(
-        [
-            input_tensor,
-            xx_channel.type_as(input_tensor),
-            yy_channel.type_as(input_tensor),
-        ],
-        dim=1,
-    )
+    ret = torch.cat([input_tensor, xx_channel.type_as(input_tensor), yy_channel.type_as(input_tensor)], dim=1)
 
     if with_r:
         rr = torch.sqrt(
-            torch.pow(xx_channel.type_as(input_tensor) - 0.5, 2)
-            + torch.pow(yy_channel.type_as(input_tensor) - 0.5, 2)
+            torch.pow(xx_channel.type_as(input_tensor) - 0.5, 2) + torch.pow(yy_channel.type_as(input_tensor) - 0.5, 2)
         )
         ret = torch.cat([ret, rr], dim=1)
 
     return ret
 
 
-"""
-An alternative implementation for PyTorch with auto-infering the x-y dimensions.
-https://github.com/mkocabas/CoordConv-pytorch/blob/master/CoordConv.py
-"""
-
-
 class AddCoords(nn.Module):
+    """
+    An alternative implementation for PyTorch with auto-infering the x-y dimensions.
+    https://github.com/mkocabas/CoordConv-pytorch/blob/master/CoordConv.py
+    """
+
     def __init__(self, with_r=False):
         super().__init__()
         self.with_r = with_r
 
-    def forward(self, input_tensor):
+    def forward(self, x):  # skipcq: PYL-W0221
         """
         Args:
-            input_tensor: shape(batch, channel, x_dim, y_dim)
+            x: shape(batch, channel, x_dim, y_dim)
         """
-        return append_coords(input_tensor, self.with_r)
+        return append_coords(x, self.with_r)
 
 
 class CoordConv(nn.Module):
@@ -68,7 +61,7 @@ class CoordConv(nn.Module):
             in_size += 1
         self.conv = nn.Conv2d(in_size, out_channels, **kwargs)
 
-    def forward(self, x):
+    def forward(self, x):  # skipcq: PYL-W0221
         ret = self.addcoords(x)
         ret = self.conv(ret)
         return ret
